@@ -27,16 +27,16 @@ def plotsklearnresult(configini,videoSetting, frameSetting):
         os.makedirs(frames_dir_out)
     counters_no = config.getint('SML settings', 'No_targets')
     vidInfPath = os.path.join(projectPath, 'logs', 'video_info.csv')
-    try:
-        mulltiAnimalIDList= config.get('Multi animal IDs', 'id_list')
-        mulltiAnimalIDList = mulltiAnimalIDList.split(",")
+    mulltiAnimalIDList= config.get('Multi animal IDs', 'id_list')
+    mulltiAnimalIDList = mulltiAnimalIDList.split(",")
+    if mulltiAnimalIDList[0] != '':
         mulltiAnimalStatus = True
-    except NoSectionError:
+    if  mulltiAnimalIDList[0] == '':
         mulltiAnimalStatus = False
+    print(mulltiAnimalStatus)
     vidinfDf = pd.read_csv(vidInfPath)
     target_names, colorList_animal_1, colorList_animal_2, loopy = [], [], [], 0
     Xcols, Ycols, Pcols = getBpNames(configini)
-
     cmap = cm.get_cmap('hot', len(Xcols) + 1)
     for i in range(cmap.N):
         rgb = list((cmap(i)[:3]))
@@ -50,7 +50,6 @@ def plotsklearnresult(configini,videoSetting, frameSetting):
             rgb = [i * 255 for i in rgb]
             rgb.reverse()
             colorList_animal_2.append(rgb)
-
     filesFound = glob.glob(csv_dir_in + '/*.csv')
     print('Processing ' + str(len(filesFound)) + ' videos ...')
 
